# Introduction

\label{introduction}

Social media have become an integral part of society, including the scientific community. Not only are popular services, such as Facebook and Twitter, used and embraced by academics (van Noorden, 2014), but platforms tailored towards the needs of researchers, like ResearchGate and Academia.edu, are highly successful (Ponte & Simon, 2011; Moran, Seaman, & Tinti-Kane, 2011). In the wake of the recent publication crisis and the rise of social media, scholarly communication and especially non-traditional metrics for science impact (altmetrics) are gaining traction. In his current project on *Understanding the Societal Impact of Research through Social Media*, Dr. Alperin et al. (n.d) points out that it is time for the scholarly communication community to take a step back and examine the theoretical frameworks that underpin how we construct research metrics, as well as how we evaluate and interpret researcher’s activities and outputs. Despite the explosion of new ‘alternative’ metrics (beyond citations), there has been little work to develop a theory of scholarly metrics, beyond the literature that exists on citations (citations, take from Haustein et al. 2015). One of the few examples that they point out is Haustein et al. (2015), who build on the existing theories of citations and propose a compound of research programs from various academic disciplines to investigate the motivations of social media behavior in scholarship (e.g., social constructivism, normative theory, and other social theories).

Despite the promising nature of this work, I propose to take a second step back, in order to further examine the very epistemological presuppositions of a research program in the field of scholarly communication, and its implications for empirical research in scholarly communication. Haustein et al.’s (2015) suggestion of a polytheoretic framework for social media behaviour exemplifies the demand for scrutiny, as the overarching term of constructivism (i.e., social, radical, and cognitive constructivism) often represents a diverging variety of assumptions about central ideas such as the nature of personhood, the existence of objective knowledge or intersubjectivity. I propose to study the conceptual scaffolding of research and practices in scholarly communication, especially in regard to epistemological assumptions, from two disjoint perspectives: the human agent (authors, readers, “sharers”, etc.) and the underlying technology used to distribute, read and share (with a special focus on social media). While the former is motivated by my experience in cognitive science and will draw inspirations from the philosophy of mind, the latter part will be chiefly guided by Dr. Feenberg’s application of critical theory to a philosophy of technology.

Coming from an engineering background and engaging in a data-driven field such as scholarly communication, I want to avoid a complete “armchair philosopher” method. As a proponent of empirically-informed philosophy (Prinz, 2008) (e.g., experimental moral philosophy, experimental epistemology), empirical data-driven research will play a vital role. Inspired by methods from phenomenological research in the brain sciences (e.g., Neurophenomenology (Varela, 1996), First-Person Neuroscience (Northoff & Heinzel, 2006)) that tries to combine first and third person data as well as traditional social sciences, I hope to bridge the gap between epistemology and methodology in scholarly communication research.

The present research proposal comprises both theoretical and practical work; the former drawing inspirations from the critical theory and philosophy of technology, and philosophy of mind; while the latter builds on the work of Dr. Alperin and his research group on scholarly communication and social media. I hope that these contributions will lead to the development of a holistic framework of scholarly communication research; holistic in a twofold way: (1) a theory that considers the individual participant in scholarly communication as an experiencing subject and the involved technology in a non-instrumentalist and critical manner and (2) avoids the “armchair philosopher” approach by embracing empirical research.




# Objectives

\label{objectives}

Scholarly communication has been changing rapidly over the last two decades. While some scholars might disagree on the specific name and details, many voices can be heard that are speaking of a revolution taking place in science communication—whether it is Harnad’s (1991) *cognitive revolution*, Cronin’s (2012) *velvet revolution*, or Nielsen’s (2016) *open science revolution*. As Sugimoto et al. (2016) observe, the common theme across all these revolutions is an increased visibility and heterogeneity of science itself, especially driven by the Web 2.0 and, more specifically, the recent of rise of social media in scholarship. Simultaneously the emergence of new vehicles of disseminating science caused an increased demand for alternative indicators and metrics of science impact—namely the aforementioned *altmetrics*. 

Despite an abundance of collectable data (scientometrics, bibliometrics, altmetrics), scholarly communication remains a profoundly human and social activity, which brings forth the question of the subjective experience of producing, disseminating and consuming knowledge. While from a positivist or instrumental rationalist standpoint it might be desirable to reduce scholarly activity to “objective” measures, I believe that an approach that acknowledges the irreducibility of the individual, might be a better fit to understand the dynamics of scholarly communication. In the fashion of empirically-informed philosophy (i.e., I want to avoid to restrict myself to purely theoretical considerations) I am planning to explore the *interplay of individuals as experiencing subjects and the community/public* from the perspective of modern scholarly communication, especially in the digital domain. 

While I want to emphasize the importance of the individual researcher's experience and contribution in scholarly communication, I believe that another essential aspect is the structure of the underlying technology. The recent changes in the way scholarly communication is practiced, as well as researched, have been strongly driven by technological advances (i.e., the use of social media to disseminate research, and the emergence of altmetrics as a form of measurement and assessment were largely enabled by technological progress, namely the advance of the social web) (Sugimoto et al., 2016). At the same time, social media and altmetrics are changing the very nature of scholarship by influencing the academic incentive system. Altmetrics just being one example, I want to engage in a critical analysis of technology in scholarly communication. I will use Dr. Feenberg’s work in the critical theory of technology, especially the instrumentalization theory, which combines approaches from the philosophy of technology as well as empirical, constructivist methods. This framework, a “synthesis of theoretical and empirical approaches” (Feenberg, 2009, p.62), will serve as a scaffolding for a critical and empirical account of technology in scholarly communication.

Guided by two perspectives, one focussing on the individual actor and the other on the underlying technology, I want to evaluate current practices in scholarly communication, as well as epistemological and methodological assumptions of research in scholarly communication, social media, and altmetrics.